package Daje::Document::Builder::Html;
use Mojo::Base -base, -signatures;
use v5.40;

# NAME
# ====
#
#      Daje::Document::Builder::Html - It's the html document builder
#
#
# REQUIRES
# ========
#
# use Mojo::Base;
# use Template;
#
# DESCRIPTION
# ===========
#
# Daje::Document::Builder::Html Builds documents
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.comE<gt>
#
#

sub process($self) {

}
1;

#################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################

=head1 NAME


     Daje::Document::Builder::Html - It's the html document builder




=head1 DESCRIPTION


Daje::Document::Builder::Html Builds documents



=head1 REQUIRES


use Mojo::Base;
use Template;



=head1 METHODS

=head2 process($self)

 process($self)();

NAME
====

     Daje::Document::Builder::Html - It's the html document builder


REQUIRES
========

use Mojo::Base;
use Template;

DESCRIPTION
===========

Daje::Document::Builder::Html Builds documents

LICENSE
=======

Copyright (C) janeskil1525.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

AUTHOR
======

janeskil1525 E<lt>janeskil1525@gmail.comE<gt>





=head1 AUTHOR


janeskil1525 E<lt>janeskil1525@gmail.comE<gt>




=head1 LICENSE


Copyright (C) janeskil1525.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.



=cut

